==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/singleUseObject/MapSingleUseObjectEntityDelegate.java <==
package org.keycloak.models.map.singleUseObject;
public class MapSingleUseObjectEntityDelegate implements org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> delegateProvider;
    public MapSingleUseObjectEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public String getObjectKey() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY).getObjectKey();
    }
    @Override public void setObjectKey(String objectKey) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY, objectKey).setObjectKey(objectKey);
    }
    @Override public java.util.Map<String,String> getNotes() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES).getNotes();
    }
    @Override public void setNotes(java.util.Map<String,String> notes) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, notes).setNotes(notes);
    }
    @Override public String getNote(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, name).getNote(name);
    }
    @Override public void setNote(String key, String value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, key, value).setNote(key, value);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/singleUseObject/MapSingleUseObjectEntityDelegate.java <==
package org.keycloak.models.map.singleUseObject;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapSingleUseObjectEntityDelegate implements org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> delegateProvider;
    public MapSingleUseObjectEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public String getObjectKey() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY).getObjectKey();
    }
    @Override public void setObjectKey(String objectKey) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY, objectKey).setObjectKey(objectKey);
    }
    @Override public java.util.Map<String,String> getNotes() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES).getNotes();
    }
    @Override public void setNotes(java.util.Map<String,String> notes) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, notes).setNotes(notes);
    }
    @Override public String getNote(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, name).getNote(name);
    }
    @Override public void setNote(String key, String value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, key, value).setNote(key, value);
    }
}
